@@ -44,9 +44,9 @@ public:
     Q_INVOKABLE qreal value(int row, int column) const;
     Q_INVOKABLE void setValue(int row, int column, qreal value);
     explicit ChartModel(QObject* parent = 0);
-    int rowCount(const QModelIndex& parent) const;
-    int columnCount(const QModelIndex& parent) const;
-    QVariant data(const QModelIndex& index, int role) const;
+    int rowCount(const QModelIndex& parent) const override;
+    int columnCount(const QModelIndex& parent) const override;
+    QVariant data(const QModelIndex& index, int role) const override;
 Q_SIGNALS:
     void columnsChanged();
     void rowsChanged();
